@@ -1,6 +1,9 @@
-use fltk::{enums::*, prelude::*, *};
+use egui_backend::{
+    egui,
+    fltk::{enums::*, prelude::*, *},
+    gl, DpiScaling,
+};
 use fltk_egui as egui_backend;
-use egui_backend::{DpiScaling, egui, gl};
 use std::rc::Rc;
 use std::{cell::RefCell, time::Instant};
 
@@ -34,12 +37,8 @@ fn main() {
         | enums::Event::Resize
         | enums::Event::Move
         | enums::Event::Drag => {
-            egui_backend::input_to_egui(
-                win,
-                ev,
-                &mut state.borrow_mut(),
-                &mut painter.borrow_mut(),
-            );
+            let mut state = state.borrow_mut();
+            state.fuse_input(win, ev, &mut painter.borrow_mut());
             true
         }
         _ => false,
@@ -59,16 +58,11 @@ fn main() {
             gl::ClearColor(0.6, 0.3, 0.3, 1.0);
             gl::Clear(gl::COLOR_BUFFER_BIT);
         }
-        
+
         demo_windows.ui(&egui_ctx);
 
         let (egui_output, paint_cmds) = egui_ctx.end_frame();
-        egui_backend::translate_cursor(&mut win, &mut state.fuse_cursor, egui_output.cursor_icon);
-
-        //Handle cut, copy text from egui
-        if !egui_output.copied_text.is_empty() {
-            egui_backend::copy_to_clipboard(&mut state.clipboard, egui_output.copied_text);
-        }
+        state.fuse_output(&mut win, &egui_output);
 
         let paint_jobs = egui_ctx.tessellate(paint_cmds);
 
@@ -77,7 +71,10 @@ fn main() {
 
         win.swap_buffers();
         win.flush();
-        app::sleep(0.006);
-        app::awake();
+
+        if egui_output.needs_repaint {
+            // let egui doing some animations.
+            app::awake()
+        }
     }
 }
