@@ -1,7 +1,10 @@
-use fltk::{enums::*, prelude::*, *};
-use fltk_egui as egui_backend;
-use egui_backend::{DpiScaling, egui, gl};
 use egui::{vec2, Color32, Image};
+use egui_backend::{
+    egui,
+    fltk::{enums::*, prelude::*, *},
+    gl, DpiScaling,
+};
+use fltk_egui as egui_backend;
 use std::cell::RefCell;
 use std::rc::Rc;
 use std::time::Instant;
@@ -39,12 +42,8 @@ fn main() {
         | enums::Event::Resize
         | enums::Event::Move
         | enums::Event::Drag => {
-            egui_backend::input_to_egui(
-                win,
-                ev,
-                &mut state.borrow_mut(),
-                &mut painter.borrow_mut(),
-            );
+            let mut state = state.borrow_mut();
+            state.fuse_input(win, ev, &mut painter.borrow_mut());
             true
         }
         _ => false,
@@ -136,12 +135,7 @@ fn main() {
         });
 
         let (egui_output, paint_cmds) = egui_ctx.end_frame();
-        egui_backend::translate_cursor(&mut win, &mut state.fuse_cursor, egui_output.cursor_icon);
-
-        //Handle cut, copy text from egui
-        if !egui_output.copied_text.is_empty() {
-            fltk_egui::copy_to_clipboard(&mut state.clipboard, egui_output.copied_text);
-        }
+        state.fuse_output(&mut win, &egui_output);
 
         let paint_jobs = egui_ctx.tessellate(paint_cmds);
 
