@@ -423,8 +423,6 @@ impl Painter {
         self.upload_egui_texture(egui_texture);
         self.upload_user_textures();
 
-        let (canvas_width, canvas_height) = self.canvas_size;
-        let pixels_per_point = self.pixels_per_point;
         unsafe {
             if let Some(color) = bg_color {
                 gl::ClearColor(
@@ -436,6 +434,7 @@ impl Painter {
 
                 gl::Clear(gl::COLOR_BUFFER_BIT);
             }
+
             //Let OpenGL know we are dealing with SRGB colors so that it
             //can do the blending correctly. Not setting the framebuffer
             //leads to darkened, oversaturated colors.
@@ -445,34 +444,31 @@ impl Painter {
             gl::BlendFunc(gl::ONE, gl::ONE_MINUS_SRC_ALPHA); // premultiplied alpha
             gl::UseProgram(self.program);
             gl::ActiveTexture(gl::TEXTURE0);
-
+            let (canvas_width, canvas_height) = self.canvas_size;
+            let pixels_per_point = self.pixels_per_point;
             let u_screen_size = CString::new("u_screen_size").unwrap();
             let u_screen_size_ptr = u_screen_size.as_ptr();
             let u_screen_size_loc = gl::GetUniformLocation(self.program, u_screen_size_ptr);
-            let screen_size_pixels = vec2(canvas_width as f32, canvas_height as f32);
-            let screen_size_points = screen_size_pixels / pixels_per_point;
-            gl::Uniform2f(
-                u_screen_size_loc,
-                screen_size_points.x,
-                screen_size_points.y,
-            );
+            let (x, y) = (self.screen_rect.width(), self.screen_rect.height());
+            gl::Uniform2f(u_screen_size_loc, x, y);
             let u_sampler = CString::new("u_sampler").unwrap();
             let u_sampler_ptr = u_sampler.as_ptr();
             let u_sampler_loc = gl::GetUniformLocation(self.program, u_sampler_ptr);
             gl::Uniform1i(u_sampler_loc, 0);
-            gl::Viewport(0, 0, canvas_width as i32, canvas_height as i32);
+            gl::Viewport(0, 0, canvas_width, canvas_height);
+            let screen_x = canvas_width as f32;
+            let screen_y = canvas_height as f32;
 
             for ClippedMesh(clip_rect, mesh) in meshes {
                 gl::BindTexture(gl::TEXTURE_2D, self.get_texture(mesh.texture_id));
-
                 let clip_min_x = pixels_per_point * clip_rect.min.x;
                 let clip_min_y = pixels_per_point * clip_rect.min.y;
                 let clip_max_x = pixels_per_point * clip_rect.max.x;
                 let clip_max_y = pixels_per_point * clip_rect.max.y;
-                let clip_min_x = clip_min_x.clamp(0.0, screen_size_pixels.x);
-                let clip_min_y = clip_min_y.clamp(0.0, screen_size_pixels.y);
-                let clip_max_x = clip_max_x.clamp(clip_min_x, screen_size_pixels.x);
-                let clip_max_y = clip_max_y.clamp(clip_min_y, screen_size_pixels.y);
+                let clip_min_x = clip_min_x.clamp(0.0, x);
+                let clip_min_y = clip_min_y.clamp(0.0, y);
+                let clip_max_x = clip_max_x.clamp(clip_min_x, screen_x);
+                let clip_max_y = clip_max_y.clamp(clip_min_y, screen_y);
                 let clip_min_x = clip_min_x.round() as i32;
                 let clip_min_y = clip_min_y.round() as i32;
                 let clip_max_x = clip_max_x.round() as i32;
@@ -481,7 +477,7 @@ impl Painter {
                 //scissor Y coordinate is from the bottom
                 gl::Scissor(
                     clip_min_x,
-                    canvas_height as i32 - clip_max_y,
+                    canvas_height - clip_max_y,
                     clip_max_x - clip_min_x,
                     clip_max_y - clip_min_y,
                 );
